package db

import (
	"context"
	"fmt"
	"github.com/lin-jim-leon/kuaishou/open/user"
	"time"
	"youngee_m_api/model/gorm_model"
	"youngee_m_api/model/http_model"
)

func Authkuaishou(ctx context.Context, req *http_model.AuthkuaishouRequest) error {
	db := GetReadDB(ctx)
	fmt.Println("req", req)
	now := time.Now()
	ksuser := gorm_model.YoungeeKuaishouUserinfo{
		Ksnumber:    req.KSNumber,
		Name:        req.Name,
		PhoneNumber: req.PhoneNumber,
		CreateTime:  now,
		UpdateTime:  now,
	}
	if err := db.Create(&ksuser).Error; err != nil {
		fmt.Println("err", err)
		return err
	}
	// 返回更新后的结果
	return nil
}

func GetAuthorization(ctx context.Context, req *http_model.GetAuthorizationRequest) ([]*http_model.GetAuthorizationResponse, error) {
	db := GetReadDB(ctx)
	page := req.PageNum
	pageSize := req.PageSize
	if page < 1 {
		page = 1
	}
	if pageSize < 1 {
		pageSize = 10
	}
	offset := (page - 1) * pageSize
	ksauthorizationInfo := []gorm_model.YoungeeKuaishouUserinfo{}
	result := db.Limit(pageSize).Offset(offset).Find(&ksauthorizationInfo)
	if result.Error != nil {
		return nil, result.Error
	}

	var authorizationsInfoPointers []*http_model.GetAuthorizationResponse
	layout := "2006-01-02 15:04:05"

	for _, v := range ksauthorizationInfo {
		res := &http_model.GetAuthorizationResponse{
			Nickname:    v.NickName,
			KSNumber:    v.Ksnumber,
			Name:        v.Name,
			Phonenumber: v.PhoneNumber,
		}
		if v.AccessToken == "" {
			res.UPdatetime = ""
			res.Expired = v.Expired
		} else {
			var expiredstatus int
			_, err := user.GetUserinfo("ks651333097154138217", v.AccessToken)
			if err != nil {
				expiredstatus = 1
			} else {
				expiredstatus = 2
			}

			updateResult := db.Model(&gorm_model.YoungeeKuaishouUserinfo{}).Where("id = ?", v.Id).Update("expired", expiredstatus)
			if updateResult.Error != nil {
				return nil, updateResult.Error
			}

			res.UPdatetime = v.UpdateTime.Format(layout)
			res.Expired = expiredstatus
		}

		authorizationsInfoPointers = append(authorizationsInfoPointers, res)
	}
	return authorizationsInfoPointers, nil
}

func DeleteKsauthorization(ctx context.Context, req *http_model.DeleteKsauthorizationRequest) error {
	db := GetReadDB(ctx)
	ks := gorm_model.YoungeeKuaishouUserinfo{
		Ksnumber: req.KSNumber,
	}
	result := db.Where("ksnumber = ?", req.KSNumber).Delete(ks)
	if result.Error != nil {
		return result.Error
	}
	return nil
}
