package handler

import (
	"github.com/gin-gonic/gin"
	"github.com/sirupsen/logrus"
	"youngee_m_api/consts"
	"youngee_m_api/db"
	"youngee_m_api/model/http_model"
	"youngee_m_api/util"
)

func WrapGetRechargeCountHandler(ctx *gin.Context) {
	handler := newGetRechargeCountHandler(ctx)
	BaseRun(handler)
}

type GetRechargeCountHandler struct {
	ctx  *gin.Context
	req  *http_model.GetRechargeCountRequest
	resp *http_model.CommonResponse
}

func (g GetRechargeCountHandler) getContext() *gin.Context {
	return g.ctx
}

func (g GetRechargeCountHandler) getResponse() interface{} {
	return g.resp
}

func (g GetRechargeCountHandler) getRequest() interface{} {
	return g.req
}

func (g GetRechargeCountHandler) run() {
	data, err := db.GetRechargeCount(g.ctx)
	if err != nil {
		logrus.WithContext(g.ctx).Errorf("[GetRechargeCountHandler] error GetRechargeCount, err:%+v", err)
		util.HandlerPackErrorResp(g.resp, consts.ErrorInternal, consts.DefaultToast)
		return
	}
	g.resp.Data = data
	g.resp.Status = consts.ErrorSuccess
	g.resp.Message = "成功查询"
}

func (g GetRechargeCountHandler) checkParam() error {
	return nil
}

func newGetRechargeCountHandler(ctx *gin.Context) *GetRechargeCountHandler {
	return &GetRechargeCountHandler{
		ctx:  ctx,
		req:  http_model.NewGetRechargeCountRequest(),
		resp: http_model.NewGetRechargeCountResponse(),
	}
}
