package gorm_model

import (
	"time"
)

type YounggeeSecTaskInfo struct {
	ID                     int        `gorm:"column:id;primary_key"`              // 递增id
	TaskID                 string     `gorm:"column:task_id"`                     // 选品任务id
	SelectionID            string     `gorm:"column:selection_id"`                // 选品id
	TalentID               string     `gorm:"column:talent_id"`                   // 达人id
	AccountID              int        `gorm:"column:account_id"`                  // 账号id
	TalentPlatformInfoSnap string     `gorm:"column:talent_platform_info_snap"`   // 达人平台信息快照
	TalentPersonalInfoSnap string     `gorm:"column:talent_personal_info_snap"`   // 达人个人信息快照
	TalentPostAddrSnap     string     `gorm:"column:talent_post_addr_snap"`       // 收货地址快照
	TaskReward             string     `gorm:"column:task_reward"`                 //  达人赏金
	TalentPayment          string     `gorm:"column:talent_payment"`              // 达人垫付金额
	IsPayPayment           int        `gorm:"column:is_pay_payment"`              // 企业是否返样品钱
	IsPayReward            int        `gorm:"column:is_pay_reward"`               // 企业是否结算悬赏
	TaskMode               int        `gorm:"column:task_mode"`                   // 任务形式，1、2分别表示纯佣带货、悬赏任务
	SampleMode             int        `gorm:"column:sample_mode"`                 // 领样形式，1-3分别表示免费领样、垫付买样、不提供样品
	TaskStatus             int        `gorm:"column:task_status;default:1"`       // 任务状态 1待选 2已选 3落选
	TaskStage              int        `gorm:"column:task_stage"`                  // 任务阶段，详情见info_sec_task_stage表
	CreateDate             time.Time  `gorm:"column:create_date"`                 // 创建时间
	SelectDate             time.Time  `gorm:"column:select_date"`                 // 反选时间
	DeliveryDate           time.Time  `gorm:"column:delivery_date"`               // 发货时间
	CompleteDate           time.Time  `gorm:"column:complete_date"`               // 结束时间
	WithdrawDate           time.Time  `gorm:"column:withdraw_date"`               // 提现时间
	CompleteStatus         int        `gorm:"column:complete_status;default:1"`   // 结束方式 1未结束 2正常结束 3反选失败
	LogisticsStatus        int        `gorm:"column:logistics_status;default:1"`  // 发货状态 1 待发货 2已发货 3 已签收
	AssignmentStatus       uint       `gorm:"column:assignment_status;default:1"` // 作业上传状态 1-5分别代表待添加、已添加、待修改、已修改、已通过
	UpdateAt               time.Time  `gorm:"column:update_at"`                   // 更新时间
	WithdrawStatus         int        `gorm:"column:withdraw_status;default:1"`   // 提现状态，1-4分别代表不可提现、可提现、提现中、已提现
	LeadTeamID             string     `gorm:"column:lead_team_id"`                // 作为团长的young之团id，对应younggee_talent_team中的team_id字段
	TeamID                 string     `gorm:"column:team_id"`                     // 作为团员的young之团id，对应younggee_talent_team中的team_id字段
	TeamIncome             int        `gorm:"column:team_income"`                 // young之团团长现金收益
	TeamPoint              int        `gorm:"column:team_point"`                  // young之团团长积分收益
	SignedTime             time.Time  `gorm:"column:signed_time"`                 // 快递签收时间
	SaleNum                int        `gorm:"column:sale_num"`                    // 30天橱窗销量
	FreeStrategyId         int        `gorm:"column:free_strategy_id"`            // 免费领样策略id
	ProductId              int        `gorm:"column:product_id"`                  // 商品id
	SaleActual             int        `gorm:"column:sale_actual"`                 // 实际带货量
	SaleNumAll             int        `gorm:"column:sale_num_all"`                // 达人对此商品的全部销售量（大于1表示已出单）
	FansNum                int        `gorm:"column:fans_num"`                    // 粉丝数
	FreeStage              int        `gorm:"column:free_stage"`                  // 免费领样阶段,1-5分别代表已申请、已拒绝、待发货、已发货、已收货
	RewardStage            int        `gorm:"column:reward_stage"`                // 悬赏阶段,1-2分别代表待结算(管理后台设置)、已结算（小程序端设置）
	TaskDDL                *time.Time `gorm:"column:task_ddl" json:"task_ddl" comment:"和选品ddl保持一致"`
	City                   string     `gorm:"column:city;size:255" json:"city" comment:"所在城市"`
	OpenID                 string     `gorm:"column:open_id;size:255" json:"open_id" comment:"账号唯一标识"`
	WxNum                  string     `gorm:"column:wx_num;size:255" json:"wx_num" comment:"微信号"`
	BOperator              string     `gorm:"column:b_operator;size:255" json:"b_operator" comment:"ID"`
	CreateLogisticUserType int        `gorm:"column:create_logistic_user_type"` // 创建快递单类型
	CreateLogisticUserId   string     `gorm:"column:create_logistic_user_id"`   // 创建快递单ID
	ChooseTalentUserId     string     `gorm:"column:choose_talent_user_id"`     // 同意/拒绝达人操作人ID
	ChooseTalentUserType   int        `gorm:"column:choose_talent_user_type"`   // 同意/拒绝达人操作人类型，1商家，2子账号，3管理后台
}

func (m *YounggeeSecTaskInfo) TableName() string {
	return "younggee_sec_task_info"
}
